\name{reduce.ind.exons}
\alias{reduce.ind.exons}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Reducing matrix of exons usage }
\description{
  Computes the grouping of exons that best preserves information
  about each specific transcript. The grouping is done independently
  of the exons order.
}
\usage{
reduce.ind.exons(M)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{M}{ binary (e.g. with 1 and 0) matrix of exons per
    transcript usage (see details), obtained from a GeneStructure object.}
}
\details{
  From an indicator matrix of exons per transcript usage (accessed with
  \code{g$I} from a GeneStructure \code{g}), this function computes a
  projection matrix \code{F} that maximally merges the set of exons unique
  to a transcript. The matrix \code{F} and the modified exon usage are
  returned as a list with two elements.
}
\value{
  A list with two elements:
  \item{F }{Matrix of transformation obtained to merge the exons. I\%*\%F
    or exons.length \%*\% F can be used to give the new exons usage and
    length, respectively.}
  \item{I.red }{The reduced matrix of exons usage. Note that this is not
  a binary matrix as it also summarizes the number of exons used for
  each merged position.}
}
\references{ \link{solas.website} }
\author{ Hugues Richard }
\seealso{  \code{\link{gene.new}} and the references
  herein. \code{\link{MaxSubSpace}} for assessing which transcripts can
  be estimated without ambiguities.
}
\examples{
## A gene with 3 transcripts and 6 exons.
I.orig = matrix( c(1,1,1,0,1,0,
                   1,1,1,1,0,1,
                   1,1,0,1,0,1),
nrow = 3, ncol = 6, byrow = TRUE)
I.orig

reduce.ind.exons(I.orig)
### The reduced matrix has 4 exons.
### To get the matrix itself:
apply(reduce.ind.exons(I.orig)$I.red > 0, 2, as.integer)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
