\name{gene.new}
\alias{gene.new}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Create a gene structure }
\description{
  Create a GeneStructure object from 3 tables giving respectively: general
  informations, positions of exons, and exon usage. See details
  for a description of required fields in various tables.
}
\usage{
gene.new(info, indicator, exons.pos, read.length = 27)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{info}{ The \code{info} table is a 1 line data frame or a list containing
    the basic description for the gene. This must contain the elements
    \code{nexons} the number of exons, \code{name}, the identifier for
    the gene, \code{chr} the chromosome identifier for the gene,
    \code{direction} the strand on which the gene is encoded (for ease
    of notation, the ordering of exons is always done from 5' to 3'
    on the genomic leading strand),
    \code{nforms} the total number of forms for the transcript.}
  \item{indicator}{ A data.frame with \code{nforms} rows and 
    \code{nexons+2} columns. The two first columns encode respectively the
    name of the gene and the name for the different isoforms. The \code{nexons}
  last columns have to be labelled E1, E2,..., E\code{nexons}}
  \item{exons.pos}{ A data.frame with \code{nexons} rows. Columns named
    \code{begin} and \code{end} are mandatory. Columns named
    \code{n.unique.hits} can be added to be used instead of the length
    in the \code{\link{EstimateProportions}} or the
    \code{\link{ASI.test.default}} functions.
  }
  \item{read.length}{Length of a read. Only needed by the
    CutFromConnexJunction function.}
}
\details{
  The gene.new function is the simplest function to create a
  \code{GeneStructure} object. The arguments used in the present form are meant
  to ease the process of creation for multiple genes at the same
  time, by applying the function to lists of data frames.
}
\value{
  A \code{GeneStructure} object which can be seen as a list with elements:
  \item{name}{The identifier of the gene}
  \item{chr}{The chromosome where the gene is encoded.}
  \item{names}{The names of the transcript isoforms.}
  \item{I.big}{The indicator matrix of exons usage for each isoform}
  \item{exons.pos}{A data frame with the positions of every exons
    composing the gene. }
}
\references{Solas.paper. }
\author{Hugues Richard}
\seealso{Functions to operate on gene object
  \code{\link{merge.transcripts}}, or
  to interact with the set of junctions \code{\link{CutFromConnexeJunction}} and
  \code{\link{GenerateJunctionMatrix}}
}
%   and of general use: \code{\link{reduce.ind.exons}},
%   \code{\link{transcripts.length}}, \code{\link{dist.bp.ensembl}},
%   \code{\link{gene2gff}}
% }

\examples{
###
###Information for an hypothetical gene with 3 forms and 4 exons
###
transcript.names = c("Form1" ,"Form2", "Form3", "Form4")
gene.info = data.frame(name = "MyGene", chr = "chr0", nexons = 5, direction = "+", nforms = 4)
#matrix of forms usage
I = matrix(c(1,0,1,0,0,1,1,1,0,0,0,0,1,0,1,0,0,1,1,1), ncol= 5, byrow =TRUE)
I
colnames(I) = paste("E", 1:5, sep = "")
trans.structure = data.frame( gene = "MyGene", form = transcript.names, I)
##all exons have length 150 with introns of length 300
exons.coord = data.frame(gene = "MyGene", chr = "chr0", 
  subexon = paste("E", 1:5, sep = ""),
  begin = cumsum(c(1, rep(450-1, 4))), 
  end =  cumsum(c(150, rep(450-1, 4))))
mygene = gene.new(gene.info, trans.structure, exons.coord)

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~gene}
\keyword{ ~creator }% __ONLY ONE__ keyword per line
